@@ -99,6 +99,14 @@ class VariableList2D:
     def magnitude(self):
         return np.linalg.norm(self.value)
 
+    @property
+    def with_unit(self):
+        return f"{self.value} {self.unit}"
+
+    @property
+    def name_val(self):
+        return f"{self.var_name}: {self.with_unit}"
+
 
 def scatter_2d(x_list, y_list, do_x=False):
     if isinstance(x_list, VariableList):
