@@ -124,3 +124,10 @@ def drag_force(rho, v, C, A):
     :param A: Cross-sectional Area (m^2)
     """
     return (1 / 2) * rho * (v**2) * C * A
+
+
+def print_all(**args):
+    out = ""
+    for arg in args:
+        out += arg.value.name_val + ", "
+    print(out)
